Vendor Policy
-------------
Cpenv vendors packages:

- To ease the use of cpenv in environments that do not support
  pip.
- To ensure that cpenv itself is vendorable as a library.
- When packages are unavailable via pypi.


Vendored Packages
-----------------
appdirs==1.4.4
cachetools==3.1.1
certifi==2020.04.05.1
pyyaml==5.3.1
shotgun_api3==3.2.4
terminalsize - https://gist.github.com/jtriley/1108174
